Python Elasticsearch Client
===========================

Welcome to the API documentation of the official Python client for Elasticsearch!
The goal of this client is to provide common ground for all Elasticsearch-related
code in Python; because of this it tries to be opinion-free and very extendable.

High-level documentation for this client is `also available <https://www.elastic.co/docs/reference/elasticsearch/clients/python>`_.

.. toctree::
   :maxdepth: 2 

   es_api
   esql
   dsl
   api_helpers
   exceptions

.. toctree::
   :caption: Async
   :maxdepth: 2

   async_es_api
   async_dsl
   async_api_helpers


License
-------

Copyright 2023 Elasticsearch B.V. Licensed under the Apache License, Version 2.0.


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
